@@ -417,12 +417,54 @@ class RDPClientQTGUI(QMainWindow):
 
 	def mousePressEvent(self, e):
 		self.send_mouse(e, True)
+
+def get_help():
+	from asysocks.unicomm.common.target import UniTarget
+	from asyauth.common.credentials import UniCredential
+
+	protocols = """RDP : RDP protocol
+	VNC: VNC protocol"""
+	authprotos = """ntlm     : CREDSSP+NTLM authentication
+	kerberos : CREDSSP+Kerberos authentication
+	sspi-ntlm: CREDSSP+NTLM authentication using current user's creds (Windows only, restricted admin mode only)
+	sspi-kerberos: CREDSSP+KERBEROS authentication using current user's creds (Windows only, restricted admin mode only)
+	plain    : Old username and password authentication (only works when NLA is disabled on the server)
+	none     : No authentication (same as plain, but no provided credentials needed)
+	"""
+	usage = UniCredential.get_help(protocols, authprotos, '')
+	usage += UniTarget.get_help()
+	usage += """
+RDP Examples:
+	Login with no credentials (only works when NLA is disabled on the server):
+		rdp://10.10.10.2
+	Login with username and password (only works when NLA is disabled on the server):
+		rdp://TEST\Administrator:Passw0rd!1@10.10.10.2
+	Login via CREDSSP+NTLM:
+		rdp+ntlm-password://TEST\Administrator:Passw0rd!1@10.10.10.2
+	Login via CREDSSP+Kerberos:
+		rdp+kerberos-password://TEST\Administrator:Passw0rd!1@win2019ad.test.corp/?dc=10.10.10.2
+	Login via CREDSSP+NTLM using current user's creds (Windows only, restricted admin mode only):
+		rdp+sspi-ntlm://win2019ad.test.corp
+	Login via CREDSSP+Kerberos using current user's creds (Windows only, restricted admin mode only):
+		rdp+sspi-kerberos://win2019ad.test.corp/
+	...
 	
+VNC examples:
+	Login with no credentials:
+		vnc://10.10.10.2
+	Login with password (the short way):
+		vnc://Passw0rd!1@10.10.10.2
+	Login with password:
+		vnc+plain-password://Passw0rd!1@10.10.10.2
+"""
+	return usage
 
 def main():
+	from aardwolf.extensions.RDPEDYC.vchannels.socksoverrdp import SocksOverRDPChannel
+
 	import logging
 	import argparse
-	parser = argparse.ArgumentParser(description='Async RDP Client. Duckyscript will be executed by pressing ESC 3 times')
+	parser = argparse.ArgumentParser(description='Async RDP Client. Duckyscript will be executed by pressing ESC 3 times', usage=get_help())
 	parser.add_argument('-v', '--verbose', action='count', default=0, help='Verbosity, can be stacked')
 	parser.add_argument('--no-mouse-hover', action='store_false', help='Disables sending mouse hovering data. (saves bandwith)')
 	parser.add_argument('--no-keyboard', action='store_false', help='Disables keyboard input. (whatever)')
@@ -431,6 +473,9 @@ def main():
 	parser.add_argument('--keyboard', default = 'enus', help='Keyboard on the client side. Used for VNC and duckyscript')
 	parser.add_argument('--ducky', help='Ducky script to be executed')
 	parser.add_argument('--duckydelay', type=int, default=-1, help='Ducky script autostart delayed')
+	parser.add_argument('--sockschannel', default = 'SocksChannel', help='-extra- The virtual channel name of the remote SOCKS proxy')
+	parser.add_argument('--socksip', default = '127.0.0.1', help='-extra- Listen IP for SOCKS server')
+	parser.add_argument('--socksport', default = 1080, help='-extra- Listen port for SOCKS server')
 	parser.add_argument('url', help="RDP connection url")
 
 	args = parser.parse_args()
@@ -455,8 +500,8 @@ def main():
 	iosettings.video_bpp_min = 15 #servers dont support 8 any more :/
 	iosettings.video_bpp_max = args.bpp
 	iosettings.video_out_format = VIDEO_FORMAT.QT5
-	iosettings.client_keyboard = args.keyboard
-	
+	iosettings.client_keyboard = args.keyboard	
+	iosettings.vchannels[args.sockschannel] = SocksOverRDPChannel(args.sockschannel, args.socksip, args.socksport)
 
 	settings = RDPClientConsoleSettings(args.url, iosettings)
 	settings.mhover = args.no_mouse_hover
